# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/network/dubbo_proxy/v2alpha1/dubbo_proxy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/network/dubbo_proxy/v2alpha1/dubbo_proxy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.filter.network.dubbo_proxy.v2alpha1 import route_pb2 as envoy_dot_config_dot_filter_dot_network_dot_dubbo__proxy_dot_v2alpha1_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBenvoy/config/filter/network/dubbo_proxy/v2alpha1/dubbo_proxy.proto\x12\x30\x65nvoy.config.filter.network.dubbo_proxy.v2alpha1\x1a<envoy/config/filter/network/dubbo_proxy/v2alpha1/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa8\x03\n\nDubboProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12_\n\rprotocol_type\x18\x02 \x01(\x0e\x32>.envoy.config.filter.network.dubbo_proxy.v2alpha1.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12i\n\x12serialization_type\x18\x03 \x01(\x0e\x32\x43.envoy.config.filter.network.dubbo_proxy.v2alpha1.SerializationTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x0croute_config\x18\x04 \x03(\x0b\x32\x44.envoy.config.filter.network.dubbo_proxy.v2alpha1.RouteConfiguration\x12T\n\rdubbo_filters\x18\x05 \x03(\x0b\x32=.envoy.config.filter.network.dubbo_proxy.v2alpha1.DubboFilter\"J\n\x0b\x44ubboFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any*\x19\n\x0cProtocolType\x12\t\n\x05\x44ubbo\x10\x00*!\n\x11SerializationType\x12\x0c\n\x08Hessian2\x10\x00\x42\xeb\x01\n>io.envoyproxy.envoy.config.filter.network.dubbo_proxy.v2alpha1B\x0f\x44ubboProxyProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/dubbo_proxy/v2alpha1\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.dubbo_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.dubbo_proxy.v2alpha1.dubbo_proxy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n>io.envoyproxy.envoy.config.filter.network.dubbo_proxy.v2alpha1B\017DubboProxyProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/dubbo_proxy/v2alpha1\362\230\376\217\0051\022/envoy.extensions.filters.network.dubbo_proxy.v3\272\200\310\321\006\002\020\001'
  _globals['_DUBBOPROXY'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_DUBBOPROXY'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_DUBBOPROXY'].fields_by_name['protocol_type']._loaded_options = None
  _globals['_DUBBOPROXY'].fields_by_name['protocol_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_DUBBOPROXY'].fields_by_name['serialization_type']._loaded_options = None
  _globals['_DUBBOPROXY'].fields_by_name['serialization_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_DUBBOFILTER'].fields_by_name['name']._loaded_options = None
  _globals['_DUBBOFILTER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_PROTOCOLTYPE']._serialized_start=800
  _globals['_PROTOCOLTYPE']._serialized_end=825
  _globals['_SERIALIZATIONTYPE']._serialized_start=827
  _globals['_SERIALIZATIONTYPE']._serialized_end=860
  _globals['_DUBBOPROXY']._serialized_start=298
  _globals['_DUBBOPROXY']._serialized_end=722
  _globals['_DUBBOFILTER']._serialized_start=724
  _globals['_DUBBOFILTER']._serialized_end=798
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/health/v3/hds.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/health/v3/hds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import health_check_pb2 as envoy_dot_config_dot_core_dot_v3_dot_health__check__pb2
from envoy.config.endpoint.v3 import endpoint_components_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/service/health/v3/hds.proto\x12\x17\x65nvoy.service.health.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/config/core/v3/health_check.proto\x1a\x32\x65nvoy/config/endpoint/v3/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb2\x01\n\nCapability\x12L\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32,.envoy.service.health.v3.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02:,\x9a\xc5\x88\x1e\'\n%envoy.service.discovery.v2.Capability\"\xad\x01\n\x12HealthCheckRequest\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x37\n\ncapability\x18\x02 \x01(\x0b\x32#.envoy.service.health.v3.Capability:4\x9a\xc5\x88\x1e/\n-envoy.service.discovery.v2.HealthCheckRequest\"\xb3\x01\n\x0e\x45ndpointHealth\x12\x34\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\".envoy.config.endpoint.v3.Endpoint\x12\x39\n\rhealth_status\x18\x02 \x01(\x0e\x32\".envoy.config.core.v3.HealthStatus:0\x9a\xc5\x88\x1e+\n)envoy.service.discovery.v2.EndpointHealth\"\x8e\x01\n\x17LocalityEndpointsHealth\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12\x41\n\x10\x65ndpoints_health\x18\x02 \x03(\x0b\x32\'.envoy.service.health.v3.EndpointHealth\"\x83\x01\n\x16\x43lusterEndpointsHealth\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12S\n\x19locality_endpoints_health\x18\x02 \x03(\x0b\x32\x30.envoy.service.health.v3.LocalityEndpointsHealth\"\xf5\x01\n\x16\x45ndpointHealthResponse\x12N\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32\'.envoy.service.health.v3.EndpointHealthB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12Q\n\x18\x63luster_endpoints_health\x18\x02 \x03(\x0b\x32/.envoy.service.health.v3.ClusterEndpointsHealth:8\x9a\xc5\x88\x1e\x33\n1envoy.service.discovery.v2.EndpointHealthResponse\"\xac\x02\n*HealthCheckRequestOrEndpointHealthResponse\x12K\n\x14health_check_request\x18\x01 \x01(\x0b\x32+.envoy.service.health.v3.HealthCheckRequestH\x00\x12S\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32/.envoy.service.health.v3.EndpointHealthResponseH\x00:L\x9a\xc5\x88\x1eG\nEenvoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponseB\x0e\n\x0crequest_type\"\xb1\x01\n\x11LocalityEndpoints\x12\x30\n\x08locality\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Locality\x12\x35\n\tendpoints\x18\x02 \x03(\x0b\x32\".envoy.config.endpoint.v3.Endpoint:3\x9a\xc5\x88\x1e.\n,envoy.service.discovery.v2.LocalityEndpoints\"\xfb\x02\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x38\n\rhealth_checks\x18\x02 \x03(\x0b\x32!.envoy.config.core.v3.HealthCheck\x12\x46\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32*.envoy.service.health.v3.LocalityEndpoints\x12W\n\x18transport_socket_matches\x18\x04 \x03(\x0b\x32\x35.envoy.config.cluster.v3.Cluster.TransportSocketMatch\x12>\n\x14upstream_bind_config\x18\x05 \x01(\x0b\x32 .envoy.config.core.v3.BindConfig:4\x9a\xc5\x88\x1e/\n-envoy.service.discovery.v2.ClusterHealthCheck\"\xc7\x01\n\x14HealthCheckSpecifier\x12J\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32+.envoy.service.health.v3.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:6\x9a\xc5\x88\x1e\x31\n/envoy.service.discovery.v2.HealthCheckSpecifier\"\n\n\x08HdsDummy2\xd8\x02\n\x16HealthDiscoveryService\x12\x8d\x01\n\x11StreamHealthCheck\x12\x43.envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse\x1a-.envoy.service.health.v3.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xad\x01\n\x10\x46\x65tchHealthCheck\x12\x43.envoy.service.health.v3.HealthCheckRequestOrEndpointHealthResponse\x1a-.envoy.service.health.v3.HealthCheckSpecifier\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v3/discovery:health_check:\x01*B\x84\x01\n%io.envoyproxy.envoy.service.health.v3B\x08HdsProtoP\x01ZGgithub.com/envoyproxy/go-control-plane/envoy/service/health/v3;healthv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.health.v3.hds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%io.envoyproxy.envoy.service.health.v3B\010HdsProtoP\001ZGgithub.com/envoyproxy/go-control-plane/envoy/service/health/v3;healthv3\272\200\310\321\006\002\020\002'
  _globals['_CAPABILITY']._loaded_options = None
  _globals['_CAPABILITY']._serialized_options = b'\232\305\210\036\'\n%envoy.service.discovery.v2.Capability'
  _globals['_HEALTHCHECKREQUEST']._loaded_options = None
  _globals['_HEALTHCHECKREQUEST']._serialized_options = b'\232\305\210\036/\n-envoy.service.discovery.v2.HealthCheckRequest'
  _globals['_ENDPOINTHEALTH']._loaded_options = None
  _globals['_ENDPOINTHEALTH']._serialized_options = b'\232\305\210\036+\n)envoy.service.discovery.v2.EndpointHealth'
  _globals['_ENDPOINTHEALTHRESPONSE'].fields_by_name['endpoints_health']._loaded_options = None
  _globals['_ENDPOINTHEALTHRESPONSE'].fields_by_name['endpoints_health']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_ENDPOINTHEALTHRESPONSE']._loaded_options = None
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_options = b'\232\305\210\0363\n1envoy.service.discovery.v2.EndpointHealthResponse'
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._loaded_options = None
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_options = b'\232\305\210\036G\nEenvoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse'
  _globals['_LOCALITYENDPOINTS']._loaded_options = None
  _globals['_LOCALITYENDPOINTS']._serialized_options = b'\232\305\210\036.\n,envoy.service.discovery.v2.LocalityEndpoints'
  _globals['_CLUSTERHEALTHCHECK']._loaded_options = None
  _globals['_CLUSTERHEALTHCHECK']._serialized_options = b'\232\305\210\036/\n-envoy.service.discovery.v2.ClusterHealthCheck'
  _globals['_HEALTHCHECKSPECIFIER']._loaded_options = None
  _globals['_HEALTHCHECKSPECIFIER']._serialized_options = b'\232\305\210\0361\n/envoy.service.discovery.v2.HealthCheckSpecifier'
  _globals['_HEALTHDISCOVERYSERVICE'].methods_by_name['FetchHealthCheck']._loaded_options = None
  _globals['_HEALTHDISCOVERYSERVICE'].methods_by_name['FetchHealthCheck']._serialized_options = b'\202\323\344\223\002\037\"\032/v3/discovery:health_check:\001*'
  _globals['_CAPABILITY']._serialized_start=429
  _globals['_CAPABILITY']._serialized_end=607
  _globals['_CAPABILITY_PROTOCOL']._serialized_start=521
  _globals['_CAPABILITY_PROTOCOL']._serialized_end=561
  _globals['_HEALTHCHECKREQUEST']._serialized_start=610
  _globals['_HEALTHCHECKREQUEST']._serialized_end=783
  _globals['_ENDPOINTHEALTH']._serialized_start=786
  _globals['_ENDPOINTHEALTH']._serialized_end=965
  _globals['_LOCALITYENDPOINTSHEALTH']._serialized_start=968
  _globals['_LOCALITYENDPOINTSHEALTH']._serialized_end=1110
  _globals['_CLUSTERENDPOINTSHEALTH']._serialized_start=1113
  _globals['_CLUSTERENDPOINTSHEALTH']._serialized_end=1244
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_start=1247
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_end=1492
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_start=1495
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_end=1795
  _globals['_LOCALITYENDPOINTS']._serialized_start=1798
  _globals['_LOCALITYENDPOINTS']._serialized_end=1975
  _globals['_CLUSTERHEALTHCHECK']._serialized_start=1978
  _globals['_CLUSTERHEALTHCHECK']._serialized_end=2357
  _globals['_HEALTHCHECKSPECIFIER']._serialized_start=2360
  _globals['_HEALTHCHECKSPECIFIER']._serialized_end=2559
  _globals['_HDSDUMMY']._serialized_start=2561
  _globals['_HDSDUMMY']._serialized_end=2571
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_start=2574
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_end=2918
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/tracers/opentelemetry/samplers/v3/dynatrace_sampler.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/tracers/opentelemetry/samplers/v3/dynatrace_sampler.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import http_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJenvoy/extensions/tracers/opentelemetry/samplers/v3/dynatrace_sampler.proto\x12\x32\x65nvoy.extensions.tracers.opentelemetry.samplers.v3\x1a\'envoy/config/core/v3/http_service.proto\x1a\x1dudpa/annotations/status.proto\"\x94\x01\n\x16\x44ynatraceSamplerConfig\x12\x0e\n\x06tenant\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\x05\x12\x37\n\x0chttp_service\x18\x03 \x01(\x0b\x32!.envoy.config.core.v3.HttpService\x12\x1d\n\x15root_spans_per_minute\x18\x04 \x01(\rB\xc9\x01\n@io.envoyproxy.envoy.extensions.tracers.opentelemetry.samplers.v3B\x15\x44ynatraceSamplerProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/samplers/v3;samplersv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.tracers.opentelemetry.samplers.v3.dynatrace_sampler_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n@io.envoyproxy.envoy.extensions.tracers.opentelemetry.samplers.v3B\025DynatraceSamplerProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/samplers/v3;samplersv3\272\200\310\321\006\002\020\002'
  _globals['_DYNATRACESAMPLERCONFIG']._serialized_start=203
  _globals['_DYNATRACESAMPLERCONFIG']._serialized_end=351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.extensions.access_loggers.grpc.v3 import als_pb2 as envoy_dot_extensions_dot_access__loggers_dot_grpc_dot_v3_dot_als__pb2
from opentelemetry.proto.common.v1 import common_pb2 as opentelemetry_dot_proto_dot_common_dot_v1_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/access_loggers/open_telemetry/v3/logs_service.proto\x12\x31\x65nvoy.extensions.access_loggers.open_telemetry.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x31\x65nvoy/extensions/access_loggers/grpc/v3/als.proto\x1a*opentelemetry/proto/common/v1/common.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xba\x03\n\x1cOpenTelemetryAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1e\n\x16\x64isable_builtin_labels\x18\x05 \x01(\x08\x12H\n\x13resource_attributes\x18\x04 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueList\x12\x35\n\x04\x62ody\x18\x02 \x01(\x0b\x32\'.opentelemetry.proto.common.v1.AnyValue\x12?\n\nattributes\x18\x03 \x01(\x0b\x32+.opentelemetry.proto.common.v1.KeyValueList\x12\x13\n\x0bstat_prefix\x18\x06 \x01(\t\x12>\n\nformatters\x18\x07 \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\xc8\x01\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\x10LogsServiceProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.open_telemetry.v3.logs_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.access_loggers.open_telemetry.v3B\020LogsServiceProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/open_telemetry/v3;open_telemetryv3\272\200\310\321\006\002\020\002'
  _globals['_OPENTELEMETRYACCESSLOGCONFIG'].fields_by_name['common_config']._loaded_options = None
  _globals['_OPENTELEMETRYACCESSLOGCONFIG'].fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_start=313
  _globals['_OPENTELEMETRYACCESSLOGCONFIG']._serialized_end=755
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/metadata/v3/metadata.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/metadata/v3/metadata.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/type/metadata/v3/metadata.proto\x12\x16\x65nvoy.type.metadata.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x85\x02\n\x0bMetadataKey\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12G\n\x04path\x18\x02 \x03(\x0b\x32/.envoy.type.metadata.v3.MetadataKey.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1al\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.type.metadata.v2.MetadataKey.PathSegmentB\x0e\n\x07segment\x12\x03\xf8\x42\x01:)\x9a\xc5\x88\x1e$\n\"envoy.type.metadata.v2.MetadataKey\"\xb3\x04\n\x0cMetadataKind\x12?\n\x07request\x18\x01 \x01(\x0b\x32,.envoy.type.metadata.v3.MetadataKind.RequestH\x00\x12;\n\x05route\x18\x02 \x01(\x0b\x32*.envoy.type.metadata.v3.MetadataKind.RouteH\x00\x12?\n\x07\x63luster\x18\x03 \x01(\x0b\x32,.envoy.type.metadata.v3.MetadataKind.ClusterH\x00\x12\x39\n\x04host\x18\x04 \x01(\x0b\x32).envoy.type.metadata.v3.MetadataKind.HostH\x00\x1a=\n\x07Request:2\x9a\xc5\x88\x1e-\n+envoy.type.metadata.v2.MetadataKind.Request\x1a\x39\n\x05Route:0\x9a\xc5\x88\x1e+\n)envoy.type.metadata.v2.MetadataKind.Route\x1a=\n\x07\x43luster:2\x9a\xc5\x88\x1e-\n+envoy.type.metadata.v2.MetadataKind.Cluster\x1a\x37\n\x04Host:/\x9a\xc5\x88\x1e*\n(envoy.type.metadata.v2.MetadataKind.Host:*\x9a\xc5\x88\x1e%\n#envoy.type.metadata.v2.MetadataKindB\x0b\n\x04kind\x12\x03\xf8\x42\x01\x42\x89\x01\n$io.envoyproxy.envoy.type.metadata.v3B\rMetadataProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/type/metadata/v3;metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.metadata.v3.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$io.envoyproxy.envoy.type.metadata.v3B\rMetadataProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/type/metadata/v3;metadatav3\272\200\310\321\006\002\020\002'
  _globals['_METADATAKEY_PATHSEGMENT'].oneofs_by_name['segment']._loaded_options = None
  _globals['_METADATAKEY_PATHSEGMENT'].oneofs_by_name['segment']._serialized_options = b'\370B\001'
  _globals['_METADATAKEY_PATHSEGMENT'].fields_by_name['key']._loaded_options = None
  _globals['_METADATAKEY_PATHSEGMENT'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAKEY_PATHSEGMENT']._loaded_options = None
  _globals['_METADATAKEY_PATHSEGMENT']._serialized_options = b'\232\305\210\0360\n.envoy.type.metadata.v2.MetadataKey.PathSegment'
  _globals['_METADATAKEY'].fields_by_name['key']._loaded_options = None
  _globals['_METADATAKEY'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_METADATAKEY'].fields_by_name['path']._loaded_options = None
  _globals['_METADATAKEY'].fields_by_name['path']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_METADATAKEY']._loaded_options = None
  _globals['_METADATAKEY']._serialized_options = b'\232\305\210\036$\n\"envoy.type.metadata.v2.MetadataKey'
  _globals['_METADATAKIND_REQUEST']._loaded_options = None
  _globals['_METADATAKIND_REQUEST']._serialized_options = b'\232\305\210\036-\n+envoy.type.metadata.v2.MetadataKind.Request'
  _globals['_METADATAKIND_ROUTE']._loaded_options = None
  _globals['_METADATAKIND_ROUTE']._serialized_options = b'\232\305\210\036+\n)envoy.type.metadata.v2.MetadataKind.Route'
  _globals['_METADATAKIND_CLUSTER']._loaded_options = None
  _globals['_METADATAKIND_CLUSTER']._serialized_options = b'\232\305\210\036-\n+envoy.type.metadata.v2.MetadataKind.Cluster'
  _globals['_METADATAKIND_HOST']._loaded_options = None
  _globals['_METADATAKIND_HOST']._serialized_options = b'\232\305\210\036*\n(envoy.type.metadata.v2.MetadataKind.Host'
  _globals['_METADATAKIND'].oneofs_by_name['kind']._loaded_options = None
  _globals['_METADATAKIND'].oneofs_by_name['kind']._serialized_options = b'\370B\001'
  _globals['_METADATAKIND']._loaded_options = None
  _globals['_METADATAKIND']._serialized_options = b'\232\305\210\036%\n#envoy.type.metadata.v2.MetadataKind'
  _globals['_METADATAKEY']._serialized_start=157
  _globals['_METADATAKEY']._serialized_end=418
  _globals['_METADATAKEY_PATHSEGMENT']._serialized_start=267
  _globals['_METADATAKEY_PATHSEGMENT']._serialized_end=375
  _globals['_METADATAKIND']._serialized_start=421
  _globals['_METADATAKIND']._serialized_end=984
  _globals['_METADATAKIND_REQUEST']._serialized_start=687
  _globals['_METADATAKIND_REQUEST']._serialized_end=748
  _globals['_METADATAKIND_ROUTE']._serialized_start=750
  _globals['_METADATAKIND_ROUTE']._serialized_end=807
  _globals['_METADATAKIND_CLUSTER']._serialized_start=809
  _globals['_METADATAKIND_CLUSTER']._serialized_end=870
  _globals['_METADATAKIND_HOST']._serialized_start=872
  _globals['_METADATAKIND_HOST']._serialized_end=927
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/rpc/error_details.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/rpc/error_details.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/rpc/error_details.proto\x12\ngoogle.rpc\x1a\x1egoogle/protobuf/duration.proto\"\x93\x01\n\tErrorInfo\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x35\n\x08metadata\x18\x03 \x03(\x0b\x32#.google.rpc.ErrorInfo.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\tRetryInfo\x12.\n\x0bretry_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"2\n\tDebugInfo\x12\x15\n\rstack_entries\x18\x01 \x03(\t\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\"y\n\x0cQuotaFailure\x12\x36\n\nviolations\x18\x01 \x03(\x0b\x32\".google.rpc.QuotaFailure.Violation\x1a\x31\n\tViolation\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x95\x01\n\x13PreconditionFailure\x12=\n\nviolations\x18\x01 \x03(\x0b\x32).google.rpc.PreconditionFailure.Violation\x1a?\n\tViolation\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x83\x01\n\nBadRequest\x12?\n\x10\x66ield_violations\x18\x01 \x03(\x0b\x32%.google.rpc.BadRequest.FieldViolation\x1a\x34\n\x0e\x46ieldViolation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"7\n\x0bRequestInfo\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x14\n\x0cserving_data\x18\x02 \x01(\t\"`\n\x0cResourceInfo\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"V\n\x04Help\x12$\n\x05links\x18\x01 \x03(\x0b\x32\x15.google.rpc.Help.Link\x1a(\n\x04Link\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"3\n\x10LocalizedMessage\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\tBl\n\x0e\x63om.google.rpcB\x11\x45rrorDetailsProtoP\x01Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\xa2\x02\x03RPCb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.rpc.error_details_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.rpcB\021ErrorDetailsProtoP\001Z?google.golang.org/genproto/googleapis/rpc/errdetails;errdetails\242\002\003RPC'
  _globals['_ERRORINFO_METADATAENTRY']._loaded_options = None
  _globals['_ERRORINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ERRORINFO']._serialized_start=79
  _globals['_ERRORINFO']._serialized_end=226
  _globals['_ERRORINFO_METADATAENTRY']._serialized_start=179
  _globals['_ERRORINFO_METADATAENTRY']._serialized_end=226
  _globals['_RETRYINFO']._serialized_start=228
  _globals['_RETRYINFO']._serialized_end=287
  _globals['_DEBUGINFO']._serialized_start=289
  _globals['_DEBUGINFO']._serialized_end=339
  _globals['_QUOTAFAILURE']._serialized_start=341
  _globals['_QUOTAFAILURE']._serialized_end=462
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=413
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=462
  _globals['_PRECONDITIONFAILURE']._serialized_start=465
  _globals['_PRECONDITIONFAILURE']._serialized_end=614
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_start=551
  _globals['_PRECONDITIONFAILURE_VIOLATION']._serialized_end=614
  _globals['_BADREQUEST']._serialized_start=617
  _globals['_BADREQUEST']._serialized_end=748
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_start=696
  _globals['_BADREQUEST_FIELDVIOLATION']._serialized_end=748
  _globals['_REQUESTINFO']._serialized_start=750
  _globals['_REQUESTINFO']._serialized_end=805
  _globals['_RESOURCEINFO']._serialized_start=807
  _globals['_RESOURCEINFO']._serialized_end=903
  _globals['_HELP']._serialized_start=905
  _globals['_HELP']._serialized_end=991
  _globals['_HELP_LINK']._serialized_start=951
  _globals['_HELP_LINK']._serialized_end=991
  _globals['_LOCALIZEDMESSAGE']._serialized_start=993
  _globals['_LOCALIZEDMESSAGE']._serialized_end=1044
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/ratelimit/v2/rls.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/ratelimit/v2/rls.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.ratelimit import ratelimit_pb2 as envoy_dot_api_dot_v2_dot_ratelimit_dot_ratelimit__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/ratelimit/v2/rls.proto\x12\x1a\x65nvoy.service.ratelimit.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a&envoy/api/v2/ratelimit/ratelimit.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"y\n\x10RateLimitRequest\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12@\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32+.envoy.api.v2.ratelimit.RateLimitDescriptor\x12\x13\n\x0bhits_addend\x18\x03 \x01(\r\"\xf1\x05\n\x11RateLimitResponse\x12H\n\x0coverall_code\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v2.RateLimitResponse.Code\x12P\n\x08statuses\x18\x02 \x03(\x0b\x32>.envoy.service.ratelimit.v2.RateLimitResponse.DescriptorStatus\x12P\n\x07headers\x18\x03 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValueB\x1f\xf2\x98\xfe\x8f\x05\x19\n\x17response_headers_to_add\x12>\n\x16request_headers_to_add\x18\x04 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a\xc0\x01\n\tRateLimit\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12J\n\x04unit\x18\x02 \x01(\x0e\x32<.envoy.service.ratelimit.v2.RateLimitResponse.RateLimit.Unit\">\n\x04Unit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06SECOND\x10\x01\x12\n\n\x06MINUTE\x10\x02\x12\x08\n\x04HOUR\x10\x03\x12\x07\n\x03\x44\x41Y\x10\x04\x1a\xbd\x01\n\x10\x44\x65scriptorStatus\x12@\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x32.envoy.service.ratelimit.v2.RateLimitResponse.Code\x12N\n\rcurrent_limit\x18\x02 \x01(\x0b\x32\x37.envoy.service.ratelimit.v2.RateLimitResponse.RateLimit\x12\x17\n\x0flimit_remaining\x18\x03 \x01(\r\"+\n\x04\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0e\n\nOVER_LIMIT\x10\x02\x32\x84\x01\n\x10RateLimitService\x12p\n\x0fShouldRateLimit\x12,.envoy.service.ratelimit.v2.RateLimitRequest\x1a-.envoy.service.ratelimit.v2.RateLimitResponse\"\x00\x42\x8d\x01\n(io.envoyproxy.envoy.service.ratelimit.v2B\x08RlsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/ratelimit/v2;ratelimitv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.ratelimit.v2.rls_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(io.envoyproxy.envoy.service.ratelimit.v2B\010RlsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/ratelimit/v2;ratelimitv2\272\200\310\321\006\002\020\001'
  _globals['_RATELIMITRESPONSE'].fields_by_name['headers']._loaded_options = None
  _globals['_RATELIMITRESPONSE'].fields_by_name['headers']._serialized_options = b'\362\230\376\217\005\031\n\027response_headers_to_add'
  _globals['_RATELIMITREQUEST']._serialized_start=201
  _globals['_RATELIMITREQUEST']._serialized_end=322
  _globals['_RATELIMITRESPONSE']._serialized_start=325
  _globals['_RATELIMITRESPONSE']._serialized_end=1078
  _globals['_RATELIMITRESPONSE_RATELIMIT']._serialized_start=649
  _globals['_RATELIMITRESPONSE_RATELIMIT']._serialized_end=841
  _globals['_RATELIMITRESPONSE_RATELIMIT_UNIT']._serialized_start=779
  _globals['_RATELIMITRESPONSE_RATELIMIT_UNIT']._serialized_end=841
  _globals['_RATELIMITRESPONSE_DESCRIPTORSTATUS']._serialized_start=844
  _globals['_RATELIMITRESPONSE_DESCRIPTORSTATUS']._serialized_end=1033
  _globals['_RATELIMITRESPONSE_CODE']._serialized_start=1035
  _globals['_RATELIMITRESPONSE_CODE']._serialized_end=1078
  _globals['_RATELIMITSERVICE']._serialized_start=1081
  _globals['_RATELIMITSERVICE']._serialized_end=1213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/clusters/redis/v3/redis_cluster.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/clusters/redis/v3/redis_cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/extensions/clusters/redis/v3/redis_cluster.proto\x12\"envoy.extensions.clusters.redis.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x03\n\x12RedisClusterConfig\x12\x41\n\x14\x63luster_refresh_rate\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17\x63luster_refresh_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12<\n\x19redirect_refresh_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1aredirect_refresh_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\x19\x66\x61ilure_refresh_threshold\x18\x05 \x01(\r\x12\'\n\x1fhost_degraded_refresh_threshold\x18\x06 \x01(\r:4\x9a\xc5\x88\x1e/\n-envoy.config.cluster.redis.RedisClusterConfigB\xa2\x01\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\x11RedisClusterProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/redis/v3;redisv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.clusters.redis.v3.redis_cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\021RedisClusterProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/redis/v3;redisv3\272\200\310\321\006\002\020\002'
  _globals['_REDISCLUSTERCONFIG'].fields_by_name['cluster_refresh_rate']._loaded_options = None
  _globals['_REDISCLUSTERCONFIG'].fields_by_name['cluster_refresh_rate']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_REDISCLUSTERCONFIG'].fields_by_name['cluster_refresh_timeout']._loaded_options = None
  _globals['_REDISCLUSTERCONFIG'].fields_by_name['cluster_refresh_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_REDISCLUSTERCONFIG']._loaded_options = None
  _globals['_REDISCLUSTERCONFIG']._serialized_options = b'\232\305\210\036/\n-envoy.config.cluster.redis.RedisClusterConfig'
  _globals['_REDISCLUSTERCONFIG']._serialized_start=250
  _globals['_REDISCLUSTERCONFIG']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from envoy.service.discovery.v2 import hds_pb2 as envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2

GRPC_GENERATED_VERSION = '1.74.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in envoy/service/discovery/v2/hds_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class HealthDiscoveryServiceStub(object):
    """[#protodoc-title: Health Discovery Service (HDS)]

    HDS is Health Discovery Service. It compliments Envoy’s health checking
    service by designating this Envoy to be a healthchecker for a subset of hosts
    in the cluster. The status of these health checks will be reported to the
    management server, where it can be aggregated etc and redistributed back to
    Envoy through EDS.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamHealthCheck = channel.stream_stream(
                '/envoy.service.discovery.v2.HealthDiscoveryService/StreamHealthCheck',
                request_serializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.FromString,
                _registered_method=True)
        self.FetchHealthCheck = channel.unary_unary(
                '/envoy.service.discovery.v2.HealthDiscoveryService/FetchHealthCheck',
                request_serializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.SerializeToString,
                response_deserializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.FromString,
                _registered_method=True)


class HealthDiscoveryServiceServicer(object):
    """[#protodoc-title: Health Discovery Service (HDS)]

    HDS is Health Discovery Service. It compliments Envoy’s health checking
    service by designating this Envoy to be a healthchecker for a subset of hosts
    in the cluster. The status of these health checks will be reported to the
    management server, where it can be aggregated etc and redistributed back to
    Envoy through EDS.
    """

    def StreamHealthCheck(self, request_iterator, context):
        """1. Envoy starts up and if its can_healthcheck option in the static
        bootstrap config is enabled, sends HealthCheckRequest to the management
        server. It supplies its capabilities (which protocol it can health check
        with, what zone it resides in, etc.).
        2. In response to (1), the management server designates this Envoy as a
        healthchecker to health check a subset of all upstream hosts for a given
        cluster (for example upstream Host 1 and Host 2). It streams
        HealthCheckSpecifier messages with cluster related configuration for all
        clusters this Envoy is designated to health check. Subsequent
        HealthCheckSpecifier message will be sent on changes to:
        a. Endpoints to health checks
        b. Per cluster configuration change
        3. Envoy creates a health probe based on the HealthCheck config and sends
        it to endpoint(ip:port) of Host 1 and 2. Based on the HealthCheck
        configuration Envoy waits upon the arrival of the probe response and
        looks at the content of the response to decide whether the endpoint is
        healthy or not. If a response hasn't been received within the timeout
        interval, the endpoint health status is considered TIMEOUT.
        4. Envoy reports results back in an EndpointHealthResponse message.
        Envoy streams responses as often as the interval configured by the
        management server in HealthCheckSpecifier.
        5. The management Server collects health statuses for all endpoints in the
        cluster (for all clusters) and uses this information to construct
        EndpointDiscoveryResponse messages.
        6. Once Envoy has a list of upstream endpoints to send traffic to, it load
        balances traffic to them without additional health checking. It may
        use inline healthcheck (i.e. consider endpoint UNHEALTHY if connection
        failed to a particular endpoint to account for health status propagation
        delay between HDS and EDS).
        By default, can_healthcheck is true. If can_healthcheck is false, Cluster
        configuration may not contain HealthCheck message.
        TODO(htuch): How is can_healthcheck communicated to CDS to ensure the above
        invariant?
        TODO(htuch): Add @amb67's diagram.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchHealthCheck(self, request, context):
        """TODO(htuch): Unlike the gRPC version, there is no stream-based binding of
        request/response. Should we add an identifier to the HealthCheckSpecifier
        to bind with the response?
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HealthDiscoveryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StreamHealthCheck': grpc.stream_stream_rpc_method_handler(
                    servicer.StreamHealthCheck,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.SerializeToString,
            ),
            'FetchHealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchHealthCheck,
                    request_deserializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.FromString,
                    response_serializer=envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.discovery.v2.HealthDiscoveryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('envoy.service.discovery.v2.HealthDiscoveryService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class HealthDiscoveryService(object):
    """[#protodoc-title: Health Discovery Service (HDS)]

    HDS is Health Discovery Service. It compliments Envoy’s health checking
    service by designating this Envoy to be a healthchecker for a subset of hosts
    in the cluster. The status of these health checks will be reported to the
    management server, where it can be aggregated etc and redistributed back to
    Envoy through EDS.
    """

    @staticmethod
    def StreamHealthCheck(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/envoy.service.discovery.v2.HealthDiscoveryService/StreamHealthCheck',
            envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FetchHealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/envoy.service.discovery.v2.HealthDiscoveryService/FetchHealthCheck',
            envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckRequestOrEndpointHealthResponse.SerializeToString,
            envoy_dot_service_dot_discovery_dot_v2_dot_hds__pb2.HealthCheckSpecifier.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/transport_sockets/internal_upstream/v3/internal_upstream.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/transport_sockets/internal_upstream/v3/internal_upstream.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.metadata.v3 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOenvoy/extensions/transport_sockets/internal_upstream/v3/internal_upstream.proto\x12\x37\x65nvoy.extensions.transport_sockets.internal_upstream.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a%envoy/type/metadata/v3/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd9\x02\n\x19InternalUpstreamTransport\x12\x84\x01\n\x14passthrough_metadata\x18\x01 \x03(\x0b\x32\x66.envoy.extensions.transport_sockets.internal_upstream.v3.InternalUpstreamTransport.MetadataValueSource\x12I\n\x10transport_socket\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1aj\n\x13MetadataValueSource\x12<\n\x04kind\x18\x01 \x01(\x0b\x32$.envoy.type.metadata.v3.MetadataKindB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xdc\x01\nEio.envoyproxy.envoy.extensions.transport_sockets.internal_upstream.v3B\x15InternalUpstreamProtoP\x01Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/internal_upstream/v3;internal_upstreamv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.internal_upstream.v3.internal_upstream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nEio.envoyproxy.envoy.extensions.transport_sockets.internal_upstream.v3B\025InternalUpstreamProtoP\001Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/internal_upstream/v3;internal_upstreamv3\272\200\310\321\006\002\020\002'
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE'].fields_by_name['kind']._loaded_options = None
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE'].fields_by_name['kind']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE'].fields_by_name['name']._loaded_options = None
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_INTERNALUPSTREAMTRANSPORT'].fields_by_name['transport_socket']._loaded_options = None
  _globals['_INTERNALUPSTREAMTRANSPORT'].fields_by_name['transport_socket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_INTERNALUPSTREAMTRANSPORT']._serialized_start=269
  _globals['_INTERNALUPSTREAMTRANSPORT']._serialized_end=614
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE']._serialized_start=508
  _globals['_INTERNALUPSTREAMTRANSPORT_METADATAVALUESOURCE']._serialized_end=614
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/quic/server_preferred_address/v3/datasource.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/quic/server_preferred_address/v3/datasource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBenvoy/extensions/quic/server_preferred_address/v3/datasource.proto\x12\x31\x65nvoy.extensions.quic.server_preferred_address.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xef\x03\n&DataSourceServerPreferredAddressConfig\x12\x82\x01\n\x0bipv4_config\x18\x01 \x01(\x0b\x32m.envoy.extensions.quic.server_preferred_address.v3.DataSourceServerPreferredAddressConfig.AddressFamilyConfig\x12\x82\x01\n\x0bipv6_config\x18\x02 \x01(\x0b\x32m.envoy.extensions.quic.server_preferred_address.v3.DataSourceServerPreferredAddressConfig.AddressFamilyConfig\x1a\xba\x01\n\x13\x41\x64\x64ressFamilyConfig\x12;\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x04port\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x36\n\x0c\x64nat_address\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\xd1\x01\n?io.envoyproxy.envoy.extensions.quic.server_preferred_address.v3B\x0f\x44\x61tasourceProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/server_preferred_address/v3;server_preferred_addressv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.quic.server_preferred_address.v3.datasource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.quic.server_preferred_address.v3B\017DatasourceProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/quic/server_preferred_address/v3;server_preferred_addressv3\272\200\310\321\006\002\020\002'
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG'].fields_by_name['address']._loaded_options = None
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG'].fields_by_name['address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG']._serialized_start=211
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG']._serialized_end=706
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG']._serialized_start=520
  _globals['_DATASOURCESERVERPREFERREDADDRESSCONFIG_ADDRESSFAMILYCONFIG']._serialized_end=706
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/network/thrift_proxy/router/v3/router.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/network/thrift_proxy/router/v3/router.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/extensions/filters/network/thrift_proxy/router/v3/router.proto\x12\x37\x65nvoy.extensions.filters.network.thrift_proxy.router.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x8a\x01\n\x06Router\x12\x46\n\"close_downstream_on_upstream_error\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.thrift.router.v2alpha1.RouterB\xc7\x01\nEio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.router.v3B\x0bRouterProtoP\x01Zggithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/router/v3;routerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.router.v3.router_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nEio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.router.v3B\013RouterProtoP\001Zggithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/router/v3;routerv3\272\200\310\321\006\002\020\002'
  _globals['_ROUTER']._loaded_options = None
  _globals['_ROUTER']._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.thrift.router.v2alpha1.Router'
  _globals['_ROUTER']._serialized_start=228
  _globals['_ROUTER']._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/core/v3/backoff.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/core/v3/backoff.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"envoy/config/core/v3/backoff.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb8\x01\n\x0f\x42\x61\x63koffStrategy\x12@\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.BackoffStrategyB\x80\x01\n\"io.envoyproxy.envoy.config.core.v3B\x0c\x42\x61\x63koffProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.backoff_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\014BackoffProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _globals['_BACKOFFSTRATEGY'].fields_by_name['base_interval']._loaded_options = None
  _globals['_BACKOFFSTRATEGY'].fields_by_name['base_interval']._serialized_options = b'\372B\013\252\001\010\010\0012\004\020\300\204='
  _globals['_BACKOFFSTRATEGY'].fields_by_name['max_interval']._loaded_options = None
  _globals['_BACKOFFSTRATEGY'].fields_by_name['max_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_BACKOFFSTRATEGY']._loaded_options = None
  _globals['_BACKOFFSTRATEGY']._serialized_options = b'\232\305\210\036#\n!envoy.api.v2.core.BackoffStrategy'
  _globals['_BACKOFFSTRATEGY']._serialized_start=184
  _globals['_BACKOFFSTRATEGY']._serialized_end=368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/auth/secret.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/auth/secret.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import common_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_common__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/auth/secret.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1e\x65nvoy/api/v2/auth/common.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\"F\n\rGenericSecret\x12\x35\n\x06secret\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\"T\n\x0fSdsSecretConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\nsds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\"\xaf\x02\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0ftls_certificate\x18\x02 \x01(\x0b\x32!.envoy.api.v2.auth.TlsCertificateH\x00\x12\x46\n\x13session_ticket_keys\x18\x03 \x01(\x0b\x32\'.envoy.api.v2.auth.TlsSessionTicketKeysH\x00\x12M\n\x12validation_context\x18\x04 \x01(\x0b\x32/.envoy.api.v2.auth.CertificateValidationContextH\x00\x12:\n\x0egeneric_secret\x18\x05 \x01(\x0b\x32 .envoy.api.v2.auth.GenericSecretH\x00\x42\x06\n\x04typeB\xa3\x01\n\x1fio.envoyproxy.envoy.api.v2.authB\x0bSecretProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.auth.secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.authB\013SecretProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001'
  _globals['_GENERICSECRET'].fields_by_name['secret']._loaded_options = None
  _globals['_GENERICSECRET'].fields_by_name['secret']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_GENERICSECRET']._serialized_start=251
  _globals['_GENERICSECRET']._serialized_end=321
  _globals['_SDSSECRETCONFIG']._serialized_start=323
  _globals['_SDSSECRETCONFIG']._serialized_end=407
  _globals['_SECRET']._serialized_start=410
  _globals['_SECRET']._serialized_end=713
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/admin/v2alpha/certs.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/admin/v2alpha/certs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/admin/v2alpha/certs.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"F\n\x0c\x43\x65rtificates\x12\x36\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32 .envoy.admin.v2alpha.Certificate\"\x84\x01\n\x0b\x43\x65rtificate\x12\x38\n\x07\x63\x61_cert\x18\x01 \x03(\x0b\x32\'.envoy.admin.v2alpha.CertificateDetails\x12;\n\ncert_chain\x18\x02 \x03(\x0b\x32\'.envoy.admin.v2alpha.CertificateDetails\"\x83\x02\n\x12\x43\x65rtificateDetails\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x44\n\x11subject_alt_names\x18\x03 \x03(\x0b\x32).envoy.admin.v2alpha.SubjectAlternateName\x12\x1d\n\x15\x64\x61ys_until_expiration\x18\x04 \x01(\x04\x12.\n\nvalid_from\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"R\n\x14SubjectAlternateName\x12\r\n\x03\x64ns\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x14\n\nip_address\x18\x03 \x01(\tH\x00\x42\x06\n\x04nameBu\n!io.envoyproxy.envoy.admin.v2alphaB\nCertsProtoP\x01Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.admin.v2alpha.certs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!io.envoyproxy.envoy.admin.v2alphaB\nCertsProtoP\001Z:github.com/envoyproxy/go-control-plane/envoy/admin/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_CERTIFICATES']._serialized_start=120
  _globals['_CERTIFICATES']._serialized_end=190
  _globals['_CERTIFICATE']._serialized_start=193
  _globals['_CERTIFICATE']._serialized_end=325
  _globals['_CERTIFICATEDETAILS']._serialized_start=328
  _globals['_CERTIFICATEDETAILS']._serialized_end=587
  _globals['_SUBJECTALTERNATENAME']._serialized_start=589
  _globals['_SUBJECTALTERNATENAME']._serialized_end=671
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/listener.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/listener.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2
from envoy.api.v2.listener import udp_listener_config_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_udp__listener__config__pb2
from envoy.config.filter.accesslog.v2 import accesslog_pb2 as envoy_dot_config_dot_filter_dot_accesslog_dot_v2_dot_accesslog__pb2
from envoy.config.listener.v2 import api_listener_pb2 as envoy_dot_config_dot_listener_dot_v2_dot_api__listener__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65nvoy/api/v2/listener.proto\x12\x0c\x65nvoy.api.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a/envoy/api/v2/listener/listener_components.proto\x1a/envoy/api/v2/listener/udp_listener_config.proto\x1a\x30\x65nvoy/config/filter/accesslog/v2/accesslog.proto\x1a+envoy/config/listener/v2/api_listener.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xaa\x0b\n\x08Listener\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x35\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.AddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\rfilter_chains\x18\x03 \x03(\x0b\x32\".envoy.api.v2.listener.FilterChain\x12\x38\n\x10use_original_dst\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01\x12G\n!per_connection_buffer_limit_bytes\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x08metadata\x18\x06 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12:\n\rdeprecated_v1\x18\x07 \x01(\x0b\x32#.envoy.api.v2.Listener.DeprecatedV1\x12\x34\n\ndrain_type\x18\x08 \x01(\x0e\x32 .envoy.api.v2.Listener.DrainType\x12?\n\x10listener_filters\x18\t \x03(\x0b\x32%.envoy.api.v2.listener.ListenerFilter\x12;\n\x18listener_filters_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n$continue_on_listener_filters_timeout\x18\x11 \x01(\x08\x12/\n\x0btransparent\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08\x66reebind\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\r \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\x12@\n\x1atcp_fast_open_queue_length\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11traffic_direction\x18\x10 \x01(\x0e\x32#.envoy.api.v2.core.TrafficDirection\x12\x45\n\x13udp_listener_config\x18\x12 \x01(\x0b\x32(.envoy.api.v2.listener.UdpListenerConfig\x12;\n\x0c\x61pi_listener\x18\x13 \x01(\x0b\x32%.envoy.config.listener.v2.ApiListener\x12Q\n\x19\x63onnection_balance_config\x18\x14 \x01(\x0b\x32..envoy.api.v2.Listener.ConnectionBalanceConfig\x12\x12\n\nreuse_port\x18\x15 \x01(\x08\x12?\n\naccess_log\x18\x16 \x03(\x0b\x32+.envoy.config.filter.accesslog.v2.AccessLog\x1a@\n\x0c\x44\x65precatedV1\x12\x30\n\x0c\x62ind_to_port\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x94\x01\n\x17\x43onnectionBalanceConfig\x12T\n\rexact_balance\x18\x01 \x01(\x0b\x32;.envoy.api.v2.Listener.ConnectionBalanceConfig.ExactBalanceH\x00\x1a\x0e\n\x0c\x45xactBalanceB\x13\n\x0c\x62\x61lance_type\x12\x03\xf8\x42\x01\")\n\tDrainType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bMODIFY_ONLY\x10\x01J\x04\x08\x0e\x10\x0f\x42\x90\x01\n\x1aio.envoyproxy.envoy.api.v2B\rListenerProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.listener_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\rListenerProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001'
  _globals['_LISTENER_CONNECTIONBALANCECONFIG'].oneofs_by_name['balance_type']._loaded_options = None
  _globals['_LISTENER_CONNECTIONBALANCECONFIG'].oneofs_by_name['balance_type']._serialized_options = b'\370B\001'
  _globals['_LISTENER'].fields_by_name['address']._loaded_options = None
  _globals['_LISTENER'].fields_by_name['address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LISTENER'].fields_by_name['use_original_dst']._loaded_options = None
  _globals['_LISTENER'].fields_by_name['use_original_dst']._serialized_options = b'\030\001'
  _globals['_LISTENER']._serialized_start=493
  _globals['_LISTENER']._serialized_end=1943
  _globals['_LISTENER_DEPRECATEDV1']._serialized_start=1679
  _globals['_LISTENER_DEPRECATEDV1']._serialized_end=1743
  _globals['_LISTENER_CONNECTIONBALANCECONFIG']._serialized_start=1746
  _globals['_LISTENER_CONNECTIONBALANCECONFIG']._serialized_end=1894
  _globals['_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE']._serialized_start=1859
  _globals['_LISTENER_CONNECTIONBALANCECONFIG_EXACTBALANCE']._serialized_end=1873
  _globals['_LISTENER_DRAINTYPE']._serialized_start=1896
  _globals['_LISTENER_DRAINTYPE']._serialized_end=1937
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/request_id/uuid/v3/uuid.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/request_id/uuid/v3/uuid.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/extensions/request_id/uuid/v3/uuid.proto\x12#envoy.extensions.request_id.uuid.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\"\x93\x01\n\x13UuidRequestIdConfig\x12\x35\n\x11pack_trace_reason\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x45\n!use_request_id_for_trace_sampling\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x9b\x01\n1io.envoyproxy.envoy.extensions.request_id.uuid.v3B\tUuidProtoP\x01ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/request_id/uuid/v3;uuidv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.request_id.uuid.v3.uuid_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1io.envoyproxy.envoy.extensions.request_id.uuid.v3B\tUuidProtoP\001ZQgithub.com/envoyproxy/go-control-plane/envoy/extensions/request_id/uuid/v3;uuidv3\272\200\310\321\006\002\020\002'
  _globals['_UUIDREQUESTIDCONFIG']._serialized_start=151
  _globals['_UUIDREQUESTIDCONFIG']._serialized_end=298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/bootstrap/v2/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/bootstrap/v2/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import secret_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2
from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import event_service_config_pb2 as envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2
from envoy.config.metrics.v2 import stats_pb2 as envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2
from envoy.config.overload.v2alpha import overload_pb2 as envoy_dot_config_dot_overload_dot_v2alpha_dot_overload__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/bootstrap/v2/bootstrap.proto\x12\x19\x65nvoy.config.bootstrap.v2\x1a\x1e\x65nvoy/api/v2/auth/secret.proto\x1a\x1a\x65nvoy/api/v2/cluster.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a,envoy/api/v2/core/event_service_config.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\x1a#envoy/config/metrics/v2/stats.proto\x1a,envoy/config/overload/v2alpha/overload.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x0b\n\tBootstrap\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12N\n\x10static_resources\x18\x02 \x01(\x0b\x32\x34.envoy.config.bootstrap.v2.Bootstrap.StaticResources\x12P\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32\x35.envoy.config.bootstrap.v2.Bootstrap.DynamicResources\x12\x42\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32).envoy.config.bootstrap.v2.ClusterManager\x12\x36\n\nhds_config\x18\x0e \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12\x37\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\".envoy.config.metrics.v2.StatsSink\x12:\n\x0cstats_config\x18\r \x01(\x0b\x32$.envoy.config.metrics.v2.StatsConfig\x12J\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=\x12\x35\n\x08watchdog\x18\x08 \x01(\x0b\x32#.envoy.config.bootstrap.v2.Watchdog\x12/\n\x07tracing\x18\t \x01(\x0b\x32\x1e.envoy.config.trace.v2.Tracing\x12=\n\x07runtime\x18\x0b \x01(\x0b\x32\".envoy.config.bootstrap.v2.RuntimeB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x42\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32).envoy.config.bootstrap.v2.LayeredRuntime\x12/\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32 .envoy.config.bootstrap.v2.Admin\x12H\n\x10overload_manager\x18\x0f \x01(\x0b\x32..envoy.config.overload.v2alpha.OverloadManager\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x1a\x91\x01\n\x0fStaticResources\x12)\n\tlisteners\x18\x01 \x03(\x0b\x32\x16.envoy.api.v2.Listener\x12\'\n\x08\x63lusters\x18\x02 \x03(\x0b\x32\x15.envoy.api.v2.Cluster\x12*\n\x07secrets\x18\x03 \x03(\x0b\x32\x19.envoy.api.v2.auth.Secret\x1a\xba\x01\n\x10\x44ynamicResources\x12\x33\n\nlds_config\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x33\n\ncds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x36\n\nads_config\x18\x03 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSourceJ\x04\x08\x04\x10\x05J\x04\x08\n\x10\x0b\"\x9c\x01\n\x05\x41\x64min\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\t\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12+\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x37\n\x0esocket_options\x18\x04 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"\xe9\x02\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12U\n\x11outlier_detection\x18\x02 \x01(\x0b\x32:.envoy.config.bootstrap.v2.ClusterManager.OutlierDetection\x12;\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.BindConfig\x12=\n\x11load_stats_config\x18\x04 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x1ah\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12<\n\revent_service\x18\x02 \x01(\x0b\x32%.envoy.api.v2.core.EventServiceConfig\"\xd7\x01\n\x08Watchdog\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"{\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x83\x04\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12G\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.DiskLayerH\x00\x12I\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x32.envoy.config.bootstrap.v2.RuntimeLayer.AdminLayerH\x00\x12G\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayerH\x00\x1aW\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08\x1a\x0c\n\nAdminLayer\x1aO\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x0brtds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"I\n\x0eLayeredRuntime\x12\x37\n\x06layers\x18\x01 \x03(\x0b\x32\'.envoy.config.bootstrap.v2.RuntimeLayerB\x91\x01\n\'io.envoyproxy.envoy.config.bootstrap.v2B\x0e\x42ootstrapProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v2;bootstrapv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.bootstrap.v2.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.bootstrap.v2B\016BootstrapProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/bootstrap/v2;bootstrapv2\272\200\310\321\006\002\020\001'
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['stats_flush_interval']._serialized_options = b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204='
  _globals['_BOOTSTRAP'].fields_by_name['runtime']._loaded_options = None
  _globals['_BOOTSTRAP'].fields_by_name['runtime']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._loaded_options = None
  _globals['_RUNTIMELAYER'].oneofs_by_name['layer_specifier']._serialized_options = b'\370B\001'
  _globals['_RUNTIMELAYER'].fields_by_name['name']._loaded_options = None
  _globals['_RUNTIMELAYER'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_BOOTSTRAP']._serialized_start=660
  _globals['_BOOTSTRAP']._serialized_end=2068
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_start=1728
  _globals['_BOOTSTRAP_STATICRESOURCES']._serialized_end=1873
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_start=1876
  _globals['_BOOTSTRAP_DYNAMICRESOURCES']._serialized_end=2062
  _globals['_ADMIN']._serialized_start=2071
  _globals['_ADMIN']._serialized_end=2227
  _globals['_CLUSTERMANAGER']._serialized_start=2230
  _globals['_CLUSTERMANAGER']._serialized_end=2591
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_start=2487
  _globals['_CLUSTERMANAGER_OUTLIERDETECTION']._serialized_end=2591
  _globals['_WATCHDOG']._serialized_start=2594
  _globals['_WATCHDOG']._serialized_end=2809
  _globals['_RUNTIME']._serialized_start=2811
  _globals['_RUNTIME']._serialized_end=2934
  _globals['_RUNTIMELAYER']._serialized_start=2937
  _globals['_RUNTIMELAYER']._serialized_end=3452
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_start=3246
  _globals['_RUNTIMELAYER_DISKLAYER']._serialized_end=3333
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_start=3335
  _globals['_RUNTIMELAYER_ADMINLAYER']._serialized_end=3347
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_start=3349
  _globals['_RUNTIMELAYER_RTDSLAYER']._serialized_end=3428
  _globals['_LAYEREDRUNTIME']._serialized_start=3454
  _globals['_LAYEREDRUNTIME']._serialized_end=3527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/http/original_ip_detection/xff/v3/xff.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/http/original_ip_detection/xff/v3/xff.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/http/original_ip_detection/xff/v3/xff.proto\x12\x32\x65nvoy.extensions.http.original_ip_detection.xff.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\"\xbe\x01\n\tXffConfig\x12\x1c\n\x14xff_num_trusted_hops\x18\x01 \x01(\r\x12^\n\x11xff_trusted_cidrs\x18\x02 \x01(\x0b\x32\x43.envoy.extensions.http.original_ip_detection.xff.v3.XffTrustedCidrs\x12\x33\n\x0fskip_xff_append\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"A\n\x0fXffTrustedCidrs\x12.\n\x05\x63idrs\x18\x01 \x03(\x0b\x32\x1f.envoy.config.core.v3.CidrRangeB\xb7\x01\n@io.envoyproxy.envoy.extensions.http.original_ip_detection.xff.v3B\x08XffProtoP\x01Z_github.com/envoyproxy/go-control-plane/envoy/extensions/http/original_ip_detection/xff/v3;xffv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.original_ip_detection.xff.v3.xff_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n@io.envoyproxy.envoy.extensions.http.original_ip_detection.xff.v3B\010XffProtoP\001Z_github.com/envoyproxy/go-control-plane/envoy/extensions/http/original_ip_detection/xff/v3;xffv3\272\200\310\321\006\002\020\002'
  _globals['_XFFCONFIG']._serialized_start=216
  _globals['_XFFCONFIG']._serialized_end=406
  _globals['_XFFTRUSTEDCIDRS']._serialized_start=408
  _globals['_XFFTRUSTEDCIDRS']._serialized_end=473
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/gzip/v3/gzip.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/gzip/v3/gzip.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.http.compressor.v3 import compressor_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_compressor_dot_v3_dot_compressor__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/extensions/filters/http/gzip/v3/gzip.proto\x12%envoy.extensions.filters.http.gzip.v3\x1a<envoy/extensions/filters/http/compressor/v3/compressor.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc1\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12\x66\n\x11\x63ompression_level\x18\x03 \x01(\x0e\x32\x41.envoy.extensions.filters.http.gzip.v3.Gzip.CompressionLevel.EnumB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12g\n\x14\x63ompression_strategy\x18\x04 \x01(\x0e\x32?.envoy.extensions.filters.http.gzip.v3.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12K\n\ncompressor\x18\n \x01(\x0b\x32\x37.envoy.extensions.filters.http.compressor.v3.Compressor\x12>\n\nchunk_size\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \x1a{\n\x10\x43ompressionLevel\"(\n\x04\x45num\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04\x42\x45ST\x10\x01\x12\t\n\x05SPEED\x10\x02:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel\"F\n\x13\x43ompressionStrategy\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x0b\n\x07HUFFMAN\x10\x02\x12\x07\n\x03RLE\x10\x03:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.gzip.v2.GzipJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tR\x0e\x63ontent_lengthR\x0c\x63ontent_typeR\x16\x64isable_on_etag_headerR\x1dremove_accept_encoding_headerB\x9f\x01\n3io.envoyproxy.envoy.extensions.filters.http.gzip.v3B\tGzipProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gzip/v3;gzipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.gzip.v3.gzip_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3io.envoyproxy.envoy.extensions.filters.http.gzip.v3B\tGzipProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/gzip/v3;gzipv3\272\200\310\321\006\002\020\002'
  _globals['_GZIP_COMPRESSIONLEVEL']._loaded_options = None
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.http.gzip.v2.Gzip.CompressionLevel'
  _globals['_GZIP'].fields_by_name['memory_level']._loaded_options = None
  _globals['_GZIP'].fields_by_name['memory_level']._serialized_options = b'\372B\006*\004\030\t(\001'
  _globals['_GZIP'].fields_by_name['compression_level']._loaded_options = None
  _globals['_GZIP'].fields_by_name['compression_level']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_GZIP'].fields_by_name['compression_strategy']._loaded_options = None
  _globals['_GZIP'].fields_by_name['compression_strategy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_GZIP'].fields_by_name['window_bits']._loaded_options = None
  _globals['_GZIP'].fields_by_name['window_bits']._serialized_options = b'\372B\006*\004\030\017(\t'
  _globals['_GZIP'].fields_by_name['chunk_size']._loaded_options = None
  _globals['_GZIP'].fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_GZIP']._loaded_options = None
  _globals['_GZIP']._serialized_options = b'\232\305\210\036\'\n%envoy.config.filter.http.gzip.v2.Gzip'
  _globals['_GZIP']._serialized_start=277
  _globals['_GZIP']._serialized_end=1110
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_start=760
  _globals['_GZIP_COMPRESSIONLEVEL']._serialized_end=883
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_start=780
  _globals['_GZIP_COMPRESSIONLEVEL_ENUM']._serialized_end=820
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_start=885
  _globals['_GZIP_COMPRESSIONSTRATEGY']._serialized_end=955
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/servicecontrol/v1/check_error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/servicecontrol/v1/check_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.google/api/servicecontrol/v1/check_error.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x17google/rpc/status.proto\"\xae\x05\n\nCheckError\x12;\n\x04\x63ode\x18\x01 \x01(\x0e\x32-.google.api.servicecontrol.v1.CheckError.Code\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\x12\"\n\x06status\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\"\x9d\x04\n\x04\x43ode\x12\x1a\n\x16\x45RROR_CODE_UNSPECIFIED\x10\x00\x12\r\n\tNOT_FOUND\x10\x05\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x19\n\x15SERVICE_NOT_ACTIVATED\x10h\x12\x14\n\x10\x42ILLING_DISABLED\x10k\x12\x13\n\x0fPROJECT_DELETED\x10l\x12\x13\n\x0fPROJECT_INVALID\x10r\x12\x14\n\x10\x43ONSUMER_INVALID\x10}\x12\x16\n\x12IP_ADDRESS_BLOCKED\x10m\x12\x13\n\x0fREFERER_BLOCKED\x10n\x12\x16\n\x12\x43LIENT_APP_BLOCKED\x10o\x12\x16\n\x12\x41PI_TARGET_BLOCKED\x10z\x12\x13\n\x0f\x41PI_KEY_INVALID\x10i\x12\x13\n\x0f\x41PI_KEY_EXPIRED\x10p\x12\x15\n\x11\x41PI_KEY_NOT_FOUND\x10q\x12\x16\n\x12INVALID_CREDENTIAL\x10{\x12!\n\x1cNAMESPACE_LOOKUP_UNAVAILABLE\x10\xac\x02\x12\x1f\n\x1aSERVICE_STATUS_UNAVAILABLE\x10\xad\x02\x12\x1f\n\x1a\x42ILLING_STATUS_UNAVAILABLE\x10\xae\x02\x12/\n*CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE\x10\xb1\x02\x42\xea\x01\n com.google.api.servicecontrol.v1B\x0f\x43heckErrorProtoP\x01ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\xf8\x01\x01\xaa\x02\x1eGoogle.Cloud.ServiceControl.V1\xca\x02\x1eGoogle\\Cloud\\ServiceControl\\V1\xea\x02!Google::Cloud::ServiceControl::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.servicecontrol.v1.check_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.google.api.servicecontrol.v1B\017CheckErrorProtoP\001ZJcloud.google.com/go/servicecontrol/apiv1/servicecontrolpb;servicecontrolpb\370\001\001\252\002\036Google.Cloud.ServiceControl.V1\312\002\036Google\\Cloud\\ServiceControl\\V1\352\002!Google::Cloud::ServiceControl::V1'
  _globals['_CHECKERROR']._serialized_start=106
  _globals['_CHECKERROR']._serialized_end=792
  _globals['_CHECKERROR_CODE']._serialized_start=251
  _globals['_CHECKERROR_CODE']._serialized_end=792
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/route/v3/route.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/route/v3/route.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/config/route/v3/route.proto\x12\x15\x65nvoy.config.route.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x91\t\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\rvirtual_hosts\x18\x02 \x03(\x0b\x32\".envoy.config.route.v3.VirtualHost\x12)\n\x04vhds\x18\t \x01(\x0b\x32\x1b.envoy.config.route.v3.Vhds\x12/\n\x15internal_only_headers\x18\x03 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12S\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x34\n\x1aresponse_headers_to_remove\x18\x05 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12R\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12+\n#most_specific_header_mutations_wins\x18\n \x01(\x08\x12\x35\n\x11validate_clusters\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n#max_direct_response_body_size_bytes\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12P\n\x19\x63luster_specifier_plugins\x18\x0c \x03(\x0b\x32-.envoy.config.route.v3.ClusterSpecifierPlugin\x12W\n\x17request_mirror_policies\x18\r \x03(\x0b\x32\x36.envoy.config.route.v3.RouteAction.RequestMirrorPolicy\x12$\n\x1cignore_port_in_host_matching\x18\x0e \x01(\x08\x12/\n\'ignore_path_parameters_in_path_matching\x18\x0f \x01(\x08\x12\x64\n\x17typed_per_filter_config\x18\x10 \x03(\x0b\x32\x43.envoy.config.route.v3.RouteConfiguration.TypedPerFilterConfigEntry\x12\x30\n\x08metadata\x18\x11 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x1aQ\n\x19TypedPerFilterConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.RouteConfiguration\"e\n\x04Vhds\x12\x43\n\rconfig_source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:\x18\x9a\xc5\x88\x1e\x13\n\x11\x65nvoy.api.v2.VhdsB\x81\x01\n#io.envoyproxy.envoy.config.route.v3B\nRouteProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/route/v3;routev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.route.v3.route_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.route.v3B\nRouteProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/route/v3;routev3\272\200\310\321\006\002\020\002'
  _globals['_ROUTECONFIGURATION_TYPEDPERFILTERCONFIGENTRY']._loaded_options = None
  _globals['_ROUTECONFIGURATION_TYPEDPERFILTERCONFIGENTRY']._serialized_options = b'8\001'
  _globals['_ROUTECONFIGURATION'].fields_by_name['internal_only_headers']._loaded_options = None
  _globals['_ROUTECONFIGURATION'].fields_by_name['internal_only_headers']._serialized_options = b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000'
  _globals['_ROUTECONFIGURATION'].fields_by_name['response_headers_to_add']._loaded_options = None
  _globals['_ROUTECONFIGURATION'].fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_ROUTECONFIGURATION'].fields_by_name['response_headers_to_remove']._loaded_options = None
  _globals['_ROUTECONFIGURATION'].fields_by_name['response_headers_to_remove']._serialized_options = b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000'
  _globals['_ROUTECONFIGURATION'].fields_by_name['request_headers_to_add']._loaded_options = None
  _globals['_ROUTECONFIGURATION'].fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_ROUTECONFIGURATION'].fields_by_name['request_headers_to_remove']._loaded_options = None
  _globals['_ROUTECONFIGURATION'].fields_by_name['request_headers_to_remove']._serialized_options = b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000'
  _globals['_ROUTECONFIGURATION']._loaded_options = None
  _globals['_ROUTECONFIGURATION']._serialized_options = b'\232\305\210\036!\n\037envoy.api.v2.RouteConfiguration'
  _globals['_VHDS'].fields_by_name['config_source']._loaded_options = None
  _globals['_VHDS'].fields_by_name['config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_VHDS']._loaded_options = None
  _globals['_VHDS']._serialized_options = b'\232\305\210\036\023\n\021envoy.api.v2.Vhds'
  _globals['_ROUTECONFIGURATION']._serialized_start=332
  _globals['_ROUTECONFIGURATION']._serialized_end=1501
  _globals['_ROUTECONFIGURATION_TYPEDPERFILTERCONFIGENTRY']._serialized_start=1380
  _globals['_ROUTECONFIGURATION_TYPEDPERFILTERCONFIGENTRY']._serialized_end=1461
  _globals['_VHDS']._serialized_start=1503
  _globals['_VHDS']._serialized_end=1604
# @@protoc_insertion_point(module_scope)
